@@ -31,7 +31,7 @@
  * Evaluates to the micro version number of NetworkManager which this source
  * compiled against.
  */
-#define NMA_MICRO_VERSION (34)
+#define NMA_MICRO_VERSION (36)
 
 /**
  * NMA_CHECK_VERSION:
@@ -62,6 +62,7 @@
 #define NMA_VERSION_1_8_26 (NMA_ENCODE_VERSION (1, 8, 26))
 #define NMA_VERSION_1_8_28 (NMA_ENCODE_VERSION (1, 8, 28))
 #define NMA_VERSION_1_8_34 (NMA_ENCODE_VERSION (1, 8, 34))
+#define NMA_VERSION_1_8_36 (NMA_ENCODE_VERSION (1, 8, 36))
 
 /* For releases, NMA_API_VERSION is equal to NMA_VERSION.
  *
@@ -150,4 +151,10 @@
 # define NMA_AVAILABLE_IN_1_8_34
 #endif
 
+#if NMA_VERSION_MAX_ALLOWED < NMA_VERSION_1_8_36
+# define NMA_AVAILABLE_IN_1_8_36            G_UNAVAILABLE(1.8,36)
+#else
+# define NMA_AVAILABLE_IN_1_8_36
+#endif
+
 #endif  /* NMA_VERSION_H */
